from quoterz.src import analyzer as analyzer

def accept_text():
    while True:
        text = raw_input("Enter key = ")
        if text == "quit":
            break
        value = analyzer.indexer.get(text, False)
        if value:
            append_value = raw_input("")
            value = "%s. %s" %(value, append_value)
        else:
            print "type to create index"
            value = raw_input("")
        analyzer.indexer.update({text: value})
    return True

def return_text():
    text = raw_input("Enter key = ")
    if text == "quit":
        return True
    value = analyzer.indexer.get(text, False)
    if value:
        print value
    else:
        print "Key does not exists."
    return True


if __name__ == "__main__":
    option = 1
    analyzer.revisit_memory()
    while option:
        print "\n1. enter\n2. search\n3. quit\n"
        option = int(raw_input("select - "))
        if option == 1:
            accept_text()
        elif option == 2:
            return_text()
        else:
            option = False
    analyzer.remember_for_long_term()




from setuptools import setup, find_packages


setup(name= "quoterz", version="0.0.1.dev1",
        description = "Quotes taking assistant",
        long_description = "This will hold very long_description from README.",
        url = "https://github.com/adiping1",
        author = "Aditya Pingle",
        author_email = "adiping1@umbc.edu",
        license = "MIT",
        classifiers = ['Development Status :: 3 - Alpha',
                        'Intended Audience :: Developers',
                        'Topic :: Software Development :: Build Tools',
                        'License :: OSI Approved :: MIT License',
                        'Programming Language :: Python :: 2.7'],
        keywords = "sample aditya piper",
        entry_points = {
                        'console_scripts': [
                                            'quoter_assistant=quoterz:main']},
        packages = find_packages(exclude=['contrib', 'docs', 'tests']),
        project_urls = {
                        'Bug Reports': 'https://github.com/adiping1/bugs',
                        'Funding' : 'https://github.com/adiping1/funds',
                        'Say Thanks!' : 'https://github.com/adiping1/thanks',
                        'Source' : 'https://github.com/adiping1/src'
                        }
        )
        #scripts = ['sample_aditya_pingle_1/bin/sampler'],
        #install_requires = ['twine'],



from src import analyzer as analyzer
import src.interface.command_line as cmd

def main():
    option = 1
    analyzer.revisit_memory()
    while option:
        print "\n1. enter\n2. search\n3. quit\n"
        option = int(raw_input("select - "))
        if option == 1:
            cmd.accept_text()
        elif option == 2:
            cmd.return_text()
        else:
            option = False
    analyzer.remember_for_long_term()



import pickle
import errno
import os
pickle_file = None
pickle_file_name = "/volumes/brain/quoter/temp_data/my_memory.txt"
pickle_file_read_mode = "rb"
pickle_file_write_mode = "wb"
indexer = None

def revisit_memory():
    global indexer
    global pickle_file
    try:
        pickle_file = open(pickle_file_name, pickle_file_read_mode)
    except IOError, e:
        if e[0] == errno.ENOENT:
            indexer = {}
        else:
            print "IOError"
    else:
        if os.path.getsize(pickle_file_name)> 0:
            indexer = pickle.load(pickle_file)
        else:
            indexer = {}
        pickle_file.close()

def analyze_me():
    return True

def remember_for_long_term():
    global pickle_file
    pickle_file = open(pickle_file_name, pickle_file_write_mode)
    pickle.dump(indexer, pickle_file, 2)
    pickle_file.close()
